@@ -1,3 +1,3 @@
 from megrok.resourcelibrary.components import ResourceLibrary
-from megrok.resourcelibrary.directive import directory, use, include
+from megrok.resourcelibrary.directive import directory, depend, include
 from zc.resourcelibrary import need
